@@ -42,10 +42,14 @@ class Crossword_Hint(AbstractHint):
     def computeHints(self):
         game = self.game
         rows = game.s.rows
-        for i in range(len(rows)):
-            r = rows[i]
+        for r in rows:
             if r.cards:
                 continue
+            if len(game.s.talon.cards) == 0:
+                for s in game.s.reserves:
+                    if game.isValidPlay(r.id, s.getCard().rank + 1):
+                        self.addHint(5000, 1, s, r)
+                continue
             if game.isValidPlay(r.id, game.s.talon.getCard().rank + 1):
                 # TODO: Check a few moves ahead to get better hints.
                 self.addHint(5000, 1, game.s.talon, r)
@@ -191,10 +195,9 @@ class Crossword(Game):
                     else:
                         if ((count % 2) != 0 and not hasEmpties) or lastFace:
                             return False
-                        else:
-                            count = 0
-                            hasEmpties = False
-                            lastFace = True
+                        count = 0
+                        hasEmpties = False
+                        lastFace = True
             if (count % 2) != 0 and not hasEmpties:
                 return False
         return True
