@@ -33,8 +33,6 @@ from pysollib.pysolrandom import construct_random
 from pysollib.settings import DEBUG, FCS_COMMAND
 from pysollib.util import KING
 
-import six
-
 FCS_VERSION = None
 
 # ************************************************************************
@@ -194,6 +192,22 @@ class AbstractHint(HintInterface):
         if self.level >= 2:
             if game.canDealCards():
                 self.addHint(self.SCORE_DEAL, 0, game.s.talon, None)
+            # A few games have multiple waste stacks.  In these games,
+            # reserves are used for the waste stacks.  This logic will
+            # handle for those games.
+            if (not game.canDealCards() and game.s.waste is not None and
+                    len(game.s.waste.cards) > 0 and len(game.s.reserves) > 0):
+                max_cards = 0
+                reserve = None
+                for r in game.s.reserves:
+                    if r.acceptsCards(game.s.waste, game.s.waste.cards):
+                        if len(r.cards) < max_cards or reserve is None:
+                            max_cards = len(r.cards)
+                            reserve = r
+
+                if reserve is not None:
+                    self.addHint(self.SCORE_DEAL, 1, game.s.waste, reserve)
+
         return self._returnHints()
 
     # subclass
@@ -805,9 +819,8 @@ class Base_Solver_Hint:
         if m:
             self._v = int(m.group(1))
             return True
-        else:
-            self._v = None
-            return False
+        self._v = None
+        return False
 
     def run_solver(self, command, board):
         if DEBUG:
@@ -819,7 +832,7 @@ class Base_Solver_Hint:
         if os.name != 'nt':
             kw['close_fds'] = True
         p = subprocess.Popen(command, **kw)
-        bytes_board = six.binary_type(board, 'utf-8')
+        bytes_board = bytes(board, 'utf-8')
         pout, perr = p.communicate(bytes_board)
         if p.returncode in (127, 1):
             # Linux and Windows return codes for "command not found" error
@@ -863,11 +876,10 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
         if re.search('^(?:Iterations count exceeded)', line):
             self.solver_state = 'intractable'
             return True
-        elif re.search('^(?:I could not solve this game)', line):
+        if re.search('^(?:I could not solve this game)', line):
             self.solver_state = 'unsolved'
             return True
-        else:
-            return False
+        return False
 
     def _isSimpleSimon(self):
         game_type = self.game_type
@@ -876,12 +888,10 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
 
     def _addBoardLine(self, line):
         self.board += line + '\n'
-        return
 
     def _addPrefixLine(self, prefix, b):
         if b:
             self._addBoardLine(prefix + b)
-        return
 
     def importFileHelper(solver, fh, s_game):
         game = s_game.s
@@ -1018,7 +1028,7 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
                 FCS_VERSION = (5, 0, 0)
             else:
                 pout, _ = self.run_solver(FCS_COMMAND + ' --version', '')
-                s = six.text_type(pout.read(), encoding='utf-8')
+                s = str(pout.read(), encoding='utf-8')
                 m = re.search(r'version ([0-9]+)\.([0-9]+)\.([0-9]+)', s)
                 if m:
                     FCS_VERSION = (int(m.group(1)), int(m.group(2)),
@@ -1082,7 +1092,7 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
             states = 0
 
             for sbytes in pout:
-                s = six.text_type(sbytes, encoding='utf-8')
+                s = str(sbytes, encoding='utf-8')
                 if DEBUG >= 5:
                     print(s)
 
@@ -1127,7 +1137,7 @@ class FreeCellSolver_Hint(Base_Solver_Hint):
                 self.solver_state = 'unsolved'
         else:
             for sbytes in pout:
-                s = six.text_type(sbytes, encoding='utf-8')
+                s = str(sbytes, encoding='utf-8')
                 if DEBUG:
                     print(s)
                 if self._determineIfSolverState(s):
@@ -1356,7 +1366,7 @@ class BlackHoleSolver_Hint(Base_Solver_Hint):
             pout, perr = self.run_solver(command, board)
 
             for sbytes in pout:
-                s = six.text_type(sbytes, encoding='utf-8')
+                s = str(sbytes, encoding='utf-8')
                 if DEBUG >= 5:
                     print(s)
 
@@ -1390,7 +1400,7 @@ class BlackHoleSolver_Hint(Base_Solver_Hint):
         else:
             self.solver_state = result.lower()
             for sbytes in pout:
-                s = six.text_type(sbytes, encoding='utf-8')
+                s = str(sbytes, encoding='utf-8')
                 if DEBUG:
                     print(s)
 
