@@ -21,7 +21,6 @@
 #
 # ---------------------------------------------------------------------------
 
-import formatter
 import htmllib
 import os
 import sys
@@ -34,12 +33,11 @@ from gtk import gdk
 
 import pango
 
+import pysollib.formatter
 from pysollib.mfxutil import Struct, openURL
 from pysollib.mygettext import _
 from pysollib.settings import TITLE
 
-import six
-
 from tkwidget import MfxMessageDialog
 
 if __name__ == '__main__':
@@ -48,16 +46,17 @@ if __name__ == '__main__':
     import gettext
     gettext.install('pysol', d, unicode=True)
 
-REMOTE_PROTOCOLS = ('ftp:', 'gopher:', 'http:', 'mailto:', 'news:', 'telnet:')
+REMOTE_PROTOCOLS = ('ftp:', 'gopher:', 'http:', 'https:', 'mailto:', 'news:',
+                    'telnet:')
 
 
 # ************************************************************************
 # *
 # ************************************************************************
 
-class tkHTMLWriter(formatter.NullWriter):
+class tkHTMLWriter(pysollib.formatter.NullWriter):
     def __init__(self, text, viewer, app):
-        formatter.NullWriter.__init__(self)
+        pysollib.formatter.NullWriter.__init__(self)
 
         self.text = text      # gtk.TextBuffer
         self.viewer = viewer  # HTMLViewer
@@ -70,7 +69,7 @@ class tkHTMLWriter(formatter.NullWriter):
         self.indent = ''
 
     def write(self, data):
-        data = six.text_type(data)
+        data = str(data)
         self.text.insert(self.text.get_end_iter(), data, len(data))
 
     def anchor_bgn(self, href, name, type):
@@ -434,13 +433,13 @@ class HTMLViewer:
         for p in REMOTE_PROTOCOLS:
             if url.startswith(p):
                 if not openURL(url):
-                    self.errorDialog(TITLE + _('''HTML limitation:
-The %s protocol is not supported yet.
+                    self.errorDialog(_('''%(app)s HTML limitation:
+The %(protocol)s protocol is not supported yet.
 
 Please use your standard web browser
 to open the following URL:
-%s
-''') % (p, url))
+%(url)s
+''') % {'app': TITLE, 'protocol': p, 'url': url})
                 return
 
         # locate the file relative to the current url
@@ -463,11 +462,6 @@ to open the following URL:
             self.errorDialog(
                 _('Unable to service request:\n') + url + '\n\n' + str(ex))
             return
-        except Exception:
-            if file:
-                file.close()
-            self.errorDialog(_('Unable to service request:\n') + url)
-            return
 
         self.url = url
         if self.home is None:
@@ -489,7 +483,7 @@ to open the following URL:
         self.textbuffer.delete(start, end)
 
         writer = tkHTMLWriter(self.textbuffer, self, self.app)
-        fmt = formatter.AbstractFormatter(writer)
+        fmt = pysollib.formatter.AbstractFormatter(writer)
         parser = tkHTMLParser(fmt)
         parser.feed(data)
         parser.close()
